Module fair_channel

Module fair_channel 

Structs

FairQueue
Spatially distancing fair queue. First in, first out, ensuring that each group of similar values is placed as far apart as possible.
FairReceiver
Receiver half of the fair channel
FairSender
Sender half of the fair channel

Traits

FairGroup
Trait for defining grouping logic for fair queuing. Groups are determined based on group_id. None represents the control group.

Functions

fair_channel
Creates a new fair channel with the specified max group size